Installation
------------

`oedes` can be most simply installed by running

   pip install oedes

The most recent source can be obtained by running

   git clone https://github.com/mzszym/oedes

It is recommended to use `pip` for installation

   cd oedes
   
   pip install . --user

After installing, `oedes` should be checked by running quick tests:

   python -c "import oedes; oedes.test()"

The output should be similar to

   Ran 15 tests in 1.311s

   OK

